# dlairflow

[![PyPI](https://img.shields.io/pypi/v/dlairflow.svg)](https://pypi.org/project/dlairflow/) [![CI](https://github.com/astro-datalab/dlairflow/actions/workflows/CI.yml/badge.svg)](https://github.com/astro-datalab/dlairflow/actions/workflows/CI.yml) [![Coverage Status](https://coveralls.io/repos/github/astro-datalab/dlairflow/badge.svg?branch=main)](https://coveralls.io/github/astro-datalab/dlairflow?branch=main) [![RTD](https://readthedocs.org/projects/dlairflow/badge/?version=latest)](https://dlairflow.readthedocs.io/en/latest/) [![License](https://img.shields.io/pypi/l/dlairflow.svg)](https://pypi.org/project/dlairflow/)

Reusable code components for building Apache Airflow DAGs.

## License

dlairflow is free software licensed under a BSD-style 3-clause license.
For details see the ``LICENSE.md`` file.
